@@ -1,10 +1,12 @@
-#' Function to compute the P-value for a Standard t-distributed random variable.
+#' Function to compute the P-value for a Standard t-distributed
+#' random variable.
 #'
-#' It is suited to compute the P-value for any random variable following a
-#'  Standard  t probability density function. For instance, to obtain
-#'  the p-value in a t-test.
+#' It is suited to compute the P-value for any random variable
+#' following a Standard  t probability density function (pdf). For
+#' instance, to obtain the p-value in a t-test.
 #'
-#' @title Obtain the P-value for a Standard t-distributed random variable
+#' @title Obtain the P-value for a Standard t-distributed random
+#' variable
 #' @param t.value A numeric random variable following a t-student pdf
 #' distribution.
 #' @param df degrees of freedom of the random variable following a
@@ -17,7 +19,7 @@
 #' @author Christian Salas-Eljatib
 #'
 #' @examples
-#' ## Load dataset
+#' # Load dataset
 #'  df <- datana::fertiliza2
 #'  head(df)
 #'  ## Computes the t-test statistics (from the 'stats' package)
@@ -31,5 +33,8 @@
 #' @rdname pvalt
 #' @export
 #'
-#@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
-pvalt<-function(t.value,df,decnum=14){round(((1-stats::pt(abs(t.value),df))*2),decnum)}
+#+===================================================================
+pvalt<-function(t.value,df,decnum=14){
+    round(((1-stats::pt(abs(t.value),df))*2),decnum)
+}
+#+===================================================================
